@@ -13,7 +13,7 @@ lists of `TimeInterval` objects.
 import portion as p
 from astropy import units as u
 from astropy.time import Time, TimeDelta
-from portion import Interval
+from astropy.units import Quantity
 
 _EPS_TIME = 10 * u.ns
 """Allowable time threshold, this much 'out of bounds' is allowed when assuming two
@@ -44,7 +44,7 @@ class TimeInterval:
         Initial time to mark the start of the interval (only the first
         instance contained in the `Time` object is used). If specified as TimeInterval,
         it is copied into this and `end_time` is ignored.
-    end_time : Time, TimeDelta or None
+    end_time : Time, TimeDelta, Quantity or None
         End time or duration to mark the end of the interval
         (only the first instance contained in the `Time` or `TimeDelta` object is used)
         None is acceptable only when `start_time` is defined as a `TimeInterval`
@@ -74,10 +74,12 @@ class TimeInterval:
         end_inclusive=True,
     ):
 
+        start_interval = None
+        end_interval = None
         if isinstance(start_time, TimeInterval):
             # start_time is a valid TimeInterval, just copy its elements
-            start_inclusive = start_time._interval.left
-            end_inclusive = start_time._interval.right
+            start_inclusive = start_time.p_interval.left
+            end_inclusive = start_time.p_interval.right
 
             if replicate:
                 start_interval = start_time.start.replicate()
@@ -108,6 +110,12 @@ class TimeInterval:
                     start_interval = start_tmp
                     end_interval = start_tmp + end_tmp
 
+            elif isinstance(end_tmp, Quantity):
+                # end time is a Quantity, but check whether it is a valid Time Quantity
+                if end_tmp.unit.decompose().physical_type == "time":
+                    start_interval = start_tmp
+                    end_interval = start_tmp + end_tmp
+
             elif isinstance(end_tmp, Time) and not isinstance(end_tmp, TimeDelta):
                 # end time is a Time
 
@@ -130,17 +138,17 @@ class TimeInterval:
             else:
                 raise ValueError(
                     f"End time is an instance of {end_tmp.__class__()}, "
-                    f"only Time or TimeDelta classes are allowed."
+                    f"only Time, Quantity (Temporal) or TimeDelta classes are allowed."
                 )
 
         # Initialise the interval
-        self._interval: Interval = p.closed(start_interval, end_interval).replace(
+        self._interval = p.closed(start_interval, end_interval).replace(
             left=start_inclusive, right=end_inclusive
         )
 
         # Raise exception if the interval duration is too short
         # Duration guaranteed to be positive thanks to the juggling above
-        if self.duration() <= _EPS_TIME:
+        if self.duration <= _EPS_TIME:
             raise ValueError("Duration of the interval is negative or zero.")
 
     def is_in_interval(self, time):
@@ -364,6 +372,7 @@ class TimeInterval:
                 "Duration of the expanded/shrunk interval is negative or zero."
             )
 
+    @property
     def duration(self):
         """
         Computes the duration of the interval.
@@ -459,59 +468,6 @@ def _create_interval_from_portion(interval, replicate=False):
     )
 
 
-def _to_p_intervals(intervals):
-    """
-    Converts a `TimeInterval` instance or a list to an `Interval` list
-    (portion library objects).
-
-    This is usually done to merge and simplify the elements of the list.
-
-    Parameters
-    ----------
-    intervals : TimeInterval or list[TimeInterval]
-        List of intervals
-
-    Returns
-    -------
-    `Interval` object with the list of time intervals
-    """
-    # Fill the `Interval` list and merge as necessary
-    p_intervals = p.empty()
-    if isinstance(intervals, list):
-        for interval in intervals:
-            p_intervals = p_intervals.union(interval.p_interval)
-    else:
-        # intervals object is a single TimeInterval
-        p_intervals = intervals.p_interval
-
-    return p_intervals
-
-
-def _to_time_intervals(p_intervals, replicate=False):
-    """
-    Converts a `Interval` list to a `TimeInterval` list.
-
-    Parameters
-    ----------
-    p_intervals : Interval
-        List of intervals
-    replicate : bool
-        `True` to replicate (deep copy) the `Time` or `TimeDelta` objects, `False` to
-        use a shallow copy to save memory
-
-    Returns
-    -------
-    `TimeInterval` object with the list of time intervals
-    """
-    intervals: list = []
-
-    # Fill the atomic `TimeInterval` objects using the merged list
-    for p_interval in p_intervals:
-        intervals.append(_create_interval_from_portion(p_interval, replicate=replicate))
-
-    return intervals
-
-
 class TimeIntervalList:
     """
     Represent and manipulate time intervals.
@@ -556,10 +512,10 @@ class TimeIntervalList:
             # if start_times is None, then there is no time interval defined
 
             # Fill the `Interval` list and merge as necessary
-            p_intervals = _to_p_intervals(intervals)
+            p_intervals = self._to_p_intervals(intervals)
 
             # Fill the atomic `TimeInterval` objects using the merged list
-            self._intervals = _to_time_intervals(p_intervals, replicate)
+            self._intervals = self._to_time_intervals(p_intervals, replicate)
 
         # Init range of validity
         self._valid_interval = self.__init_validity_rng(
@@ -647,17 +603,17 @@ class TimeIntervalList:
         intervals are inverted.
         """
         # Convert `TimeInterval` list to `Interval`
-        p_interval = _to_p_intervals(self._intervals)
+        p_interval = self._to_p_intervals(self._intervals)
 
         # Do the inversion
         p_int_inverted = ~p_interval
 
         # Fix the ends as necessary - no inf allowed
-        p_validity = _to_p_intervals(self.validity_interval())
+        p_validity = self._to_p_intervals(self.validity_interval())
         p_int_inverted = p_int_inverted.intersection(p_validity)
 
         # Generate the `TimeInterval` list
-        intervals = _to_time_intervals(p_int_inverted, replicate=False)
+        intervals = self._to_time_intervals(p_int_inverted, replicate=False)
 
         # Create the `TimeIntervalList` object
         return TimeIntervalList(
@@ -697,6 +653,61 @@ class TimeIntervalList:
         """
         return self._valid_interval
 
+    @staticmethod
+    def _to_time_intervals(p_intervals, replicate=False):
+        """
+        Converts a `Interval` list to a `TimeInterval` list.
+
+        Parameters
+        ----------
+        p_intervals : Interval
+            List of intervals
+        replicate : bool
+            `True` to replicate (deep copy) the `Time` or `TimeDelta` objects, `False` to
+            use a shallow copy to save memory
+
+        Returns
+        -------
+        `TimeInterval` object with the list of time intervals
+        """
+        intervals: list = []
+
+        # Fill the atomic `TimeInterval` objects using the merged list
+        for p_interval in p_intervals:
+            intervals.append(
+                _create_interval_from_portion(p_interval, replicate=replicate)
+            )
+
+        return intervals
+
+    @staticmethod
+    def _to_p_intervals(intervals):
+        """
+        Converts a `TimeInterval` instance or a list to an `Interval` list
+        (portion library objects).
+
+        This is usually done to merge and simplify the elements of the list.
+
+        Parameters
+        ----------
+        intervals : TimeInterval or list[TimeInterval]
+            List of intervals
+
+        Returns
+        -------
+        `Interval` object with the list of time intervals
+        """
+        # Fill the `Interval` list and merge as necessary
+        p_intervals = p.empty()
+        if isinstance(intervals, list):
+            for interval in intervals:
+                p_intervals = p_intervals.union(interval.p_interval)
+        else:
+            # intervals object is a single TimeInterval
+            p_intervals = intervals.p_interval
+
+        return p_intervals
+
     def __str__(self):
         txt = ""
         if self._intervals:
